@@ -8,7 +8,7 @@
    opsi-nagios-connector is part of the desktop management solution opsi
    (open pc server integration) http://www.opsi.org
 
-   Copyright (C) 2010-2015 uib GmbH
+   Copyright (C) 2010-2017 uib GmbH
 
    http://www.uib.de/
 
@@ -106,7 +106,7 @@ class WorkerOpsiconfdMonitoring(WorkerOpsi):
 				moni_user = self.service.config['monitoringUser']
 				try:
 					moni_password = self.service._backend.user_getCredentials(username=moni_user)["password"]
-				except Exception,e:
+				except Exception as e:
 					logger.error(u"Password not set, please check documentation from opsi-Nagios-Connector: Have you execute user_setCredentials for User: '%s'" % moni_user)
 					return
 				logger.confidential(u"Monitoring User Credentials are: user: '%s' password: '%s'" % (moni_user, moni_password))
@@ -197,7 +197,7 @@ class WorkerOpsiconfdMonitoring(WorkerOpsi):
 				try:
 					try:
 						res = self.monitoring.checkClientStatus(clientId = clientId, excludeProductList = exclude)
-					except Exception,e:
+					except Exception as e:
 						logger.logException(e, LOG_INFO)
 						res = { "state":"3", "message":str(e) }
 						res = res = json.dumps(res)
@@ -212,6 +212,30 @@ class WorkerOpsiconfdMonitoring(WorkerOpsi):
 						result.stream = stream.IByteStream(res.encode('utf-8'))
 						return result
 
+			elif query["task"] == "checkShortProductStatus":
+				try:
+					productId = query.get("param", {}).get("productIds", [])[0]
+				except IndexError:
+					res = {"state": "3", "message": "No ProductId given"}
+					res = json.dumps(res)
+					result.stream = stream.IByteStream(res.encode('utf-8'))
+					return result
+
+				threshold = {}
+				threshold["warning"] = (query.get("param", {}).get("warning", "20%"))
+				threshold["critical"] = (query.get("param", {}).get("critical", "20%"))
+				try:
+					try:
+						res = self.monitoring.checkShortProductStatus(productId = productId, thresholds=threshold)
+					except Exception as e:
+						logger.logException(e, LOG_INFO)
+						res = { "state":"3", "message":str(e) }
+						res = json.dumps(res)
+				finally:
+					result.stream = stream.IByteStream(res.encode('utf-8'))
+					return result
+
+
 			elif query["task"] == "checkProductStatus":
 				productIds   = query.get("param", {}).get("productIds", [])
 				groupIds     = query.get("param", {}).get("groupIds", [])
@@ -223,7 +247,7 @@ class WorkerOpsiconfdMonitoring(WorkerOpsi):
 				try:
 					try:
 						res = self.monitoring.checkProductStatus(productIds = productIds, productGroups = groupIds, hostGroupIds = hostGroupIds, depotIds = depotIds, exclude = exclude, verbose = verbose)
-					except Exception,e:
+					except Exception as e:
 						logger.logException(e, LOG_INFO)
 						res = { "state":"3", "message":str(e) }
 						res = res = json.dumps(res)
@@ -241,7 +265,7 @@ class WorkerOpsiconfdMonitoring(WorkerOpsi):
 				try:
 					try:
 						res = self.monitoring.checkDepotSyncStatus(depotIds, productIds, exclude, strict, verbose)
-					except Exception,e:
+					except Exception as e:
 						logger.logException(e, LOG_INFO)
 						res = { "state":"3", "message":str(e) }
 						res = res = json.dumps(res)
@@ -262,7 +286,7 @@ class WorkerOpsiconfdMonitoring(WorkerOpsi):
 				try:
 					try:
 						res = self.monitoring.checkPluginOnClient(clientId, command, timeout,waitForEnding, captureStdErr,statebefore, output, encoding)
-					except Exception,e:
+					except Exception as e:
 						logger.logException(e, LOG_INFO)
 						res = { "state":"3", "message":str(e) }
 						res = res = json.dumps(res)
@@ -277,7 +301,7 @@ class WorkerOpsiconfdMonitoring(WorkerOpsi):
 				try:
 					try:
 						res = self.monitoring.checkOpsiWebservice(cpu, errors)
-					except Exception,e:
+					except Exception as e:
 						logger.logException(e, LOG_INFO)
 						res = { "state":"3", "message":str(e) }
 						res = json.dumps(res)
@@ -294,7 +318,7 @@ class WorkerOpsiconfdMonitoring(WorkerOpsi):
 				try:
 					try:
 						res = self.monitoring.checkOpsiDiskUsage(opsiresource=opsiresource,thresholds=threshold)
-					except Exception,e:
+					except Exception as e:
 						logger.logException(e, LOG_INFO)
 						res = { "state":"3", "message":str(e) }
 						res = json.dumps(res)
@@ -420,7 +444,74 @@ class Monitoring(object):
 						}
 		return json.dumps(result)
 
-	def checkProductStatus(self, productIds = [], productGroups = [], hostGroupIds = [], depotIds = [], exclude=[], verbose = False):
+	def checkShortProductStatus(self, productId=None, thresholds={}):
+		actionRequestOnClients = []
+		productProblemsOnClients = []
+		productVersionProblemsOnClients = []
+		uptodateClients = []
+		targetProductVersion = None
+		targetPackackeVersion = None
+
+		state = self._OK
+		message = []
+
+		warning = thresholds.get("warning", "20")
+		critical = thresholds.get("critical", "20")
+		if warning.endswith("%"): warning = warning[:-1]
+		if critical.endswith("%"): critical = critical[:-1]
+		warning = float(warning)
+		critical = float(critical)
+
+		logger.debug("Checking shortly the productStates on Clients")
+		configServer = self.service._backend.host_getObjects(type="OpsiConfigserver")[0]
+		for pod in self.service._backend.productOnDepot_getObjects(depotId=configServer.id, productId=productId):
+			targetProductVersion = pod.productVersion
+			targetPackackeVersion = pod.packageVersion
+
+		productOnClients = self.service._backend.productOnClient_getObjects(productId=productId)
+
+		if not productOnClients:
+			return self._generateResponse(self._UNKNOWN, "No ProductStates found for product '%s'" % productId)
+
+		for poc in productOnClients:
+			if poc.installationStatus != "not_installed" and poc.actionResult != "successful" and poc.actionResult != "none":
+				if not poc.clientId in productProblemsOnClients:
+					productProblemsOnClients.append(poc.clientId)
+					continue
+
+			if poc.actionRequest != 'none':
+				if not poc.clientId in actionRequestOnClients:
+					actionRequestOnClients.append(poc.clientId)
+					continue
+
+			if not poc.productVersion or not poc.packageVersion:
+				continue
+
+			if poc.productVersion != targetProductVersion or poc.packageVersion != targetPackackeVersion:
+				productVersionProblemsOnClients.append(poc.clientId)
+				continue
+
+			if poc.actionResult == "successful":
+				uptodateClients.append(poc.clientId)
+
+		message.append("'%d' ProductStates for product: '%s' found; checking for Version: '%s' and Package: '%s'" % (len(productOnClients), productId, targetProductVersion, targetPackackeVersion))
+		if uptodateClients:
+			message.append("'%d' Clients are up to date" % len(uptodateClients))
+		if actionRequestOnClients and len(actionRequestOnClients)*100/len(productOnClients) > warning:
+			state = self._WARNING
+			message.append("ActionRequest set on '%d' clients" % len(actionRequestOnClients))
+		if productProblemsOnClients:
+			message.append("Problems found on '%d' clients" % len(productProblemsOnClients))
+		if productVersionProblemsOnClients:
+			message.append("Version difference found on '%d' clients" % len(productVersionProblemsOnClients))
+
+		problemClientsCount = len(productProblemsOnClients) + len(productVersionProblemsOnClients)
+		if problemClientsCount*100/len(productOnClients) > critical:
+			state = self._CRITICAL
+
+		return self._generateResponse(state, "; ".join(message))
+
+	def checkProductStatus(self, productIds=[], productGroups=[], hostGroupIds=[], depotIds=[], exclude=[], verbose=False):
 		state = self._OK
 		clientsOnDepot = {}
 
@@ -433,7 +524,7 @@ class Monitoring(object):
 			productIds = []
 			for product in self.service._backend.objectToGroup_getIdents(groupType='ProductGroup',groupId=productGroups):
 				product = product.split(";")[2]
-				if not product in productIds:
+				if not product in productIds and product not in exclude:
 					productIds.append(product)
 		if not productIds:
 			state = self._UNKNOWN
@@ -480,8 +571,6 @@ class Monitoring(object):
 		finally:
 			self.service._backend.backend_setOptions({'addConfigStateDefaults': addConfigStateDefaults})
 
-
-
 		productOnDepotInfo = {}
 		for pod in self.service._backend.productOnDepot_getObjects(depotId = depotIds, productId = productIds):
 			if not productOnDepotInfo.has_key(pod.depotId):
@@ -509,6 +598,8 @@ class Monitoring(object):
 					productProblemsOnClient[depotId][poc.productId].append(u"%s (%s lastAction: [%s])" % (poc.clientId, poc.actionResult, poc.lastAction))
 				if not poc.productVersion or not poc.packageVersion:
 					continue
+				if not productOnDepotInfo.has_key(depotId):
+					continue
 				if poc.productVersion != productOnDepotInfo[depotId][poc.productId]["productVersion"] or \
 					poc.packageVersion != productOnDepotInfo[depotId][poc.productId]["packageVersion"]:
 					if state != self._CRITICAL:
